'''
# This file is part of pyemaps
# ___________________________
#
# pyemaps is free software for non-comercial use: you can 
# redistribute it and/or modify it under the terms of the GNU General 
# Public License as published by the Free Software Foundation, either 
# version 3 of the License, or (at your option) any later version.
#
# pyemaps is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyemaps.  If not, see <https://www.gnu.org/licenses/>.
#
# Contact supprort@emlabsoftware.com for any questions and comments.
# ___________________________
'''

from copy import copy
from .samples.si_diff import run_si_sample

rel_stage = 'Alpha'

if __name__ == '__main__':
    """
    Liveness test and other information of pemaps run on command line. 
    The purpose of the run run is to show diffraction patterns 
    generated by pyemaps for silicon crystal.

    Usage:
        python -m pyemaps -s (--sample)
        python -m pyemaps -c (--copyright)
        python -m pyemaps -v (--version)
    """
    import argparse
    import datetime
    import pkg_resources

    parser = argparse.ArgumentParser(description="pyemaps console script options parsing")
    
    parser.add_argument("-s", "--sample", type=bool, nargs="?", const=True, default=False, help="for running sample code", required=False)
    parser.add_argument("-c", "--copyright", type=bool, nargs="?", const=True, default=False, help="for checking copyright", required=False)
    parser.add_argument("-v", "--version", type=bool, nargs="?", const=True, default=False, help="for checking pyemaps version", required=False)
    
    #parsing for the arguements
    # print(f"Congratulations! you have successfully installed pyemaps!")

    args = parser.parse_args()

    #default to always print version and version

    ver = pkg_resources.require("pyemaps")[0].version + str(f" {rel_stage}")
    
    copyrit = ['Pyemaps - Transmission Electron Diffraction Simulations in Python']
    copy1 = 'Copyright @ 2021 - ' + datetime.date.today().strftime('%Y') + ' EMLab Solutions, Inc. All Rights Reserved'
    copyrit.append(copy1)
    scopyrit = '\n'.join(copyrit)

    if args.sample:
        copyrit.append('Version  ' + ver)
        print('\n'.join(copyrit))
        run_si_sample()
        exit(0)

    if args.copyright:
        print(scopyrit)
        exit(0)
    
    if args.version:
        print(f'pyemaps {ver}')
        exit(0)

    copyrit.append('Version  ' + ver)
    print('\n'.join(copyrit)) 
    